@@ -19,12 +19,12 @@ LLVMPY_AddSymbol(const char *name,
 }
 
 API_EXPORT(bool)
-LLVMPY_LoadLibraryPermanently(const char *filename, char **OutError)
+LLVMPY_LoadLibraryPermanently(const char *filename, const char **OutError)
 {
     std::string error;
     bool failed = llvm::sys::DynamicLibrary::LoadLibraryPermanently(filename, &error);
     if (failed) {
-      *OutError = strdup(error.c_str());
+      *OutError = LLVMPY_CreateString(error.c_str());
     }
     return failed;
 }
