@@ -2,9 +2,8 @@ import ctypes
 import os
 import threading
 
-from .common import _decode_string, _is_shutting_down
-from ..utils import get_library_name
-from ..six import PY2
+from llvmlite.binding.common import _decode_string, _is_shutting_down
+from llvmlite.utils import get_library_name
 
 
 def _make_opaque_ref(name):
@@ -24,8 +23,14 @@ LLVMTargetLibraryInfoRef = _make_opaque_ref("LLVMTargetLibraryInfo")
 LLVMTargetRef = _make_opaque_ref("LLVMTarget")
 LLVMTargetMachineRef = _make_opaque_ref("LLVMTargetMachine")
 LLVMMemoryBufferRef = _make_opaque_ref("LLVMMemoryBuffer")
+LLVMAttributeListIterator = _make_opaque_ref("LLVMAttributeListIterator")
+LLVMAttributeSetIterator = _make_opaque_ref("LLVMAttributeSetIterator")
 LLVMGlobalsIterator = _make_opaque_ref("LLVMGlobalsIterator")
 LLVMFunctionsIterator = _make_opaque_ref("LLVMFunctionsIterator")
+LLVMBlocksIterator = _make_opaque_ref("LLVMBlocksIterator")
+LLVMArgumentsIterator = _make_opaque_ref("LLVMArgumentsIterator")
+LLVMInstructionsIterator = _make_opaque_ref("LLVMInstructionsIterator")
+LLVMOperandsIterator = _make_opaque_ref("LLVMOperandsIterator")
 LLVMTypesIterator = _make_opaque_ref("LLVMTypesIterator")
 LLVMObjectCacheRef = _make_opaque_ref("LLVMObjectCache")
 LLVMObjectFileRef = _make_opaque_ref("LLVMObjectFile")
@@ -112,21 +117,41 @@ _lib_dir = os.path.dirname(__file__)
 
 if os.name == 'nt':
     # Append DLL directory to PATH, to allow loading of bundled CRT libraries
-    # (Windows uses PATH for DLL loading, see http://msdn.microsoft.com/en-us/library/7d83bc18.aspx).
+    # (Windows uses PATH for DLL loading, see http://msdn.microsoft.com/en-us/library/7d83bc18.aspx).  # noqa E501
     os.environ['PATH'] += ';' + _lib_dir
 
+
 _lib_name = get_library_name()
+
+
+# Possible CDLL loading paths
+_lib_paths = [
+    os.path.join(_lib_dir, _lib_name),  # Absolute
+    _lib_name,  # In PATH
+    os.path.join('.', _lib_name),  # Current directory
+]
+
+# If pkg_resources is available, try to use it to load the shared object.
+# This allows direct import from egg files.
 try:
-    lib = ctypes.CDLL(os.path.join(_lib_dir, _lib_name))
-except OSError as e:
-    # Allow finding the llvmlite DLL in the current directory, for ease
-    # of bundling with frozen applications.
+    from pkg_resources import resource_filename
+except ImportError:
+    pass
+else:
+    _lib_paths.append(resource_filename(__name__, _lib_name))
+
+
+# Try to load from all of the different paths
+for _lib_path in _lib_paths:
     try:
-        lib = ctypes.CDLL(_lib_name)
+        lib = ctypes.CDLL(_lib_path)
     except OSError:
-        if PY2:
-            raise e
-        raise
+        continue
+    else:
+        break
+else:
+    raise OSError("Could not load shared object file: {}".format(_lib_name))
+
 
 lib = _lib_wrapper(lib)
 
@@ -143,8 +168,20 @@ class OutputString(object):
     """
     _as_parameter_ = _DeadPointer()
 
-    def __init__(self, owned=True):
-        self._ptr = ctypes.c_char_p(None)
+    @classmethod
+    def from_return(cls, ptr):
+        """Constructing from a pointer returned from the C-API.
+        The pointer must be allocated with LLVMPY_CreateString.
+
+        Note
+        ----
+        Because ctypes auto-converts *restype* of *c_char_p* into a python
+        string, we must use *c_void_p* to obtain the raw pointer.
+        """
+        return cls(init=ctypes.cast(ptr, ctypes.c_char_p))
+
+    def __init__(self, owned=True, init=None):
+        self._ptr = init if init is not None else ctypes.c_char_p(None)
         self._as_parameter_ = ctypes.byref(self._ptr)
         self._owned = owned
 
@@ -180,6 +217,26 @@ class OutputString(object):
 
     __nonzero__ = __bool__
 
+    @property
+    def bytes(self):
+        """Get the raw bytes of content of the char pointer.
+        """
+        return self._ptr.value
+
+
+def ret_string(ptr):
+    """To wrap string return-value from C-API.
+    """
+    if ptr is not None:
+        return str(OutputString.from_return(ptr))
+
+
+def ret_bytes(ptr):
+    """To wrap bytes return-value from C-API.
+    """
+    if ptr is not None:
+        return OutputString.from_return(ptr).bytes
+
 
 class ObjectRef(object):
     """
@@ -252,7 +309,7 @@ class ObjectRef(object):
         if not hasattr(other, "_ptr"):
             return False
         return ctypes.addressof(self._ptr[0]) == \
-                ctypes.addressof(other._ptr[0])
+            ctypes.addressof(other._ptr[0])
 
     __nonzero__ = __bool__
 
