@@ -1,9 +1,7 @@
-from __future__ import print_function, absolute_import
-
 import contextlib
 import functools
 
-from . import instructions, types, values
+from llvmlite.ir import instructions, types, values
 
 _CMP_MAP = {
     '>': 'gt',
@@ -74,7 +72,9 @@ def _uniop_intrinsic_int(opname):
         @functools.wraps(fn)
         def wrapped(self, operand, name=''):
             if not isinstance(operand.type, types.IntType):
-                raise TypeError("expected an integer type, got %s" % operand.type)
+                raise TypeError(
+                    "expected an integer type, got %s" %
+                    operand.type)
             fn = self.module.declare_intrinsic(opname, [operand.type])
             return self.call(fn, [operand], name)
 
@@ -87,7 +87,8 @@ def _uniop_intrinsic_float(opname):
     def wrap(fn):
         @functools.wraps(fn)
         def wrapped(self, operand, name=''):
-            if not isinstance(operand.type, (types.FloatType, types.DoubleType)):
+            if not isinstance(
+                    operand.type, (types.FloatType, types.DoubleType)):
                 raise TypeError("expected a float type, got %s" % operand.type)
             fn = self.module.declare_intrinsic(opname, [operand.type])
             return self.call(fn, [operand], name)
@@ -102,10 +103,14 @@ def _uniop_intrinsic_with_flag(opname):
         @functools.wraps(fn)
         def wrapped(self, operand, flag, name=''):
             if not isinstance(operand.type, types.IntType):
-                raise TypeError("expected an integer type, got %s" % operand.type)
-            if flag.type != types.IntType(1):
+                raise TypeError(
+                    "expected an integer type, got %s" %
+                    operand.type)
+            if not(isinstance(flag.type, types.IntType) and
+                   flag.type.width == 1):
                 raise TypeError("expected an i1 type, got %s" % flag.type)
-            fn = self.module.declare_intrinsic(opname, [operand.type, flag.type])
+            fn = self.module.declare_intrinsic(
+                opname, [operand.type, flag.type])
             return self.call(fn, [operand, flag], name)
 
         return wrapped
@@ -116,7 +121,7 @@ def _uniop_intrinsic_with_flag(opname):
 def _triop_intrinsic(opname):
     def wrap(fn):
         @functools.wraps(fn)
-        def wrapped(self, a, b, c,  name=''):
+        def wrapped(self, a, b, c, name=''):
             if a.type != b.type or b.type != c.type:
                 raise TypeError(
                     "expected types to be the same, got %s, %s, %s" % (
@@ -126,7 +131,9 @@ def _triop_intrinsic(opname):
             elif not isinstance(
                     a.type,
                     (types.HalfType, types.FloatType, types.DoubleType)):
-                raise TypeError("expected an floating point type, got %s" % a.type)
+                raise TypeError(
+                    "expected an floating point type, got %s" %
+                    a.type)
             fn = self.module.declare_intrinsic(opname, [a.type, b.type, c.type])
             return self.call(fn, [a, b, c], name)
 
@@ -232,6 +239,15 @@ class IRBuilder(object):
         """
         return self.function.append_basic_block(name)
 
+    def remove(self, instr):
+        """Remove the given instruction."""
+        idx = self._block.instructions.index(instr)
+        del self._block.instructions[idx]
+        if self._block.terminator == instr:
+            self._block.terminator = None
+        if self._anchor > idx:
+            self._anchor -= 1
+
     @contextlib.contextmanager
     def goto_block(self, block):
         """
@@ -569,7 +585,8 @@ class IRBuilder(object):
             op = 'o' + _CMP_MAP[cmpop]
         else:
             op = cmpop
-        instr = instructions.FCMPInstr(self.block, op, lhs, rhs, name=name, flags=flags)
+        instr = instructions.FCMPInstr(
+            self.block, op, lhs, rhs, name=name, flags=flags)
         self._insert(instr)
         return instr
 
@@ -584,7 +601,8 @@ class IRBuilder(object):
             op = 'u' + _CMP_MAP[cmpop]
         else:
             op = cmpop
-        instr = instructions.FCMPInstr(self.block, op, lhs, rhs, name=name, flags=flags)
+        instr = instructions.FCMPInstr(
+            self.block, op, lhs, rhs, name=name, flags=flags)
         self._insert(instr)
         return instr
 
@@ -720,8 +738,8 @@ class IRBuilder(object):
             name = *ptr
         """
         if not isinstance(ptr.type, types.PointerType):
-            raise TypeError("cannot load from value of type %s (%r): not a pointer"
-                            % (ptr.type, str(ptr)))
+            msg = "cannot load from value of type %s (%r): not a pointer"
+            raise TypeError(msg % (ptr.type, str(ptr)))
         ld = instructions.LoadInstr(self.block, ptr, name)
         ld.align = align
         self._insert(ld)
@@ -733,8 +751,8 @@ class IRBuilder(object):
             *ptr = name
         """
         if not isinstance(ptr.type, types.PointerType):
-            raise TypeError("cannot store to value of type %s (%r): not a pointer"
-                            % (ptr.type, str(ptr)))
+            msg = "cannot store to value of type %s (%r): not a pointer"
+            raise TypeError(msg % (ptr.type, str(ptr)))
         if ptr.type.pointee != value.type:
             raise TypeError("cannot store %s to %s: mismatching types"
                             % (value.type, ptr.type))
@@ -749,9 +767,10 @@ class IRBuilder(object):
             name = *ptr
         """
         if not isinstance(ptr.type, types.PointerType):
-            raise TypeError("cannot load from value of type %s (%r): not a pointer"
-                            % (ptr.type, str(ptr)))
-        ld = instructions.LoadAtomicInstr(self.block, ptr, ordering, align, name)
+            msg = "cannot load from value of type %s (%r): not a pointer"
+            raise TypeError(msg % (ptr.type, str(ptr)))
+        ld = instructions.LoadAtomicInstr(
+            self.block, ptr, ordering, align, name)
         self._insert(ld)
         return ld
 
@@ -761,16 +780,16 @@ class IRBuilder(object):
             *ptr = name
         """
         if not isinstance(ptr.type, types.PointerType):
-            raise TypeError("cannot store to value of type %s (%r): not a pointer"
-                            % (ptr.type, str(ptr)))
+            msg = "cannot store to value of type %s (%r): not a pointer"
+            raise TypeError(msg % (ptr.type, str(ptr)))
         if ptr.type.pointee != value.type:
             raise TypeError("cannot store %s to %s: mismatching types"
                             % (value.type, ptr.type))
-        st = instructions.StoreAtomicInstr(self.block, value, ptr, ordering, align)
+        st = instructions.StoreAtomicInstr(
+            self.block, value, ptr, ordering, align)
         self._insert(st)
         return st
 
-
     #
     # Terminators APIs
     #
@@ -832,13 +851,15 @@ class IRBuilder(object):
 
     # Call APIs
 
-    def call(self, fn, args, name='', cconv=None, tail=False, fastmath=()):
+    def call(self, fn, args, name='', cconv=None, tail=False, fastmath=(),
+             attrs=()):
         """
         Call function *fn* with *args*:
             name = fn(args...)
         """
         inst = instructions.CallInstr(self.block, fn, args, name=name,
-                                      cconv=cconv, tail=tail, fastmath=fastmath)
+                                      cconv=cconv, tail=tail, fastmath=fastmath,
+                                      attrs=attrs)
         self._insert(inst)
         return inst
 
@@ -860,14 +881,16 @@ class IRBuilder(object):
     def store_reg(self, value, reg_type, reg_name, name=''):
         """
         Store an LLVM value inside a register
-          Example: store_reg(Constant(IntType(32), 0xAAAAAAAA), IntType(32), "eax")
+        Example:
+          store_reg(Constant(IntType(32), 0xAAAAAAAA), IntType(32), "eax")
         """
         ftype = types.FunctionType(types.VoidType(), [reg_type])
         return self.asm(ftype, "", "{%s}" % reg_name, [value], True, name)
 
-    def invoke(self, fn, args, normal_to, unwind_to, name='', cconv=None, tail=False):
-        inst = instructions.InvokeInstr(self.block, fn, args, normal_to, unwind_to, name=name,
-                                        cconv=cconv)
+    def invoke(self, fn, args, normal_to, unwind_to,
+               name='', cconv=None, tail=False):
+        inst = instructions.InvokeInstr(self.block, fn, args, normal_to,
+                                        unwind_to, name=name, cconv=cconv)
         self._set_terminator(inst)
         return inst
 
@@ -953,7 +976,8 @@ class IRBuilder(object):
         return inst
 
     def atomic_rmw(self, op, ptr, val, ordering, name=''):
-        inst = instructions.AtomicRMW(self.block, op, ptr, val, ordering, name=name)
+        inst = instructions.AtomicRMW(
+            self.block, op, ptr, val, ordering, name=name)
         self._insert(inst)
         return inst
 
@@ -990,7 +1014,8 @@ class IRBuilder(object):
 
     def fence(self, ordering, targetscope=None, name=''):
         """
-        Add a memory barrier, preventing certain reorderings of load and/or store accesses with
+        Add a memory barrier, preventing certain reorderings of load and/or
+        store accesses with
         respect to other processors and devices.
         """
         inst = instructions.Fence(self.block, ordering, targetscope, name=name)
@@ -1000,13 +1025,15 @@ class IRBuilder(object):
     @_uniop_intrinsic_int("llvm.bswap")
     def bswap(self, cond):
         """
-        Used to byte swap integer values with an even number of bytes (positive multiple of 16 bits)
+        Used to byte swap integer values with an even number of bytes (positive
+        multiple of 16 bits)
         """
 
     @_uniop_intrinsic_int("llvm.bitreverse")
     def bitreverse(self, cond):
         """
-        Reverse the bitpattern of an integer value; for example 0b10110110 becomes 0b01101101.
+        Reverse the bitpattern of an integer value; for example 0b10110110
+        becomes 0b01101101.
         """
 
     @_uniop_intrinsic_int("llvm.ctpop")
@@ -1043,7 +1070,7 @@ class IRBuilder(object):
             raise TypeError("expected a float return type")
         if not isinstance(to, (types.FloatType, types.DoubleType)):
             raise TypeError("expected a float type, got %s" % to)
-        if a.type != types.IntType(16):
+        if not (isinstance(a.type, types.IntType) and a.type.width == 16):
             raise TypeError("expected an i16 type, got %s" % a.type)
 
         opname = 'llvm.convert.from.fp16'
